@@ -20,16 +20,24 @@
 #' @examples \dontrun{
 #' # high level
 #' wt_wikicommons(name = "Malus domestica")
+#' wt_wikicommons(name = "Pinus contorta")
+#' wt_wikicommons(name = "Ursus americanus")
+#' wt_wikicommons(name = "Balaenoptera musculus")
+#' 
+#' wt_wikicommons(name = "Category:Poeae")
+#' wt_wikicommons(name = "Category:Pinaceae")
 #'
 #' # low level
 #' pg <- wt_wiki_page("https://commons.wikimedia.org/wiki/Malus_domestica")
 #' wt_wikicommons_parse(pg)
 #'
 #' # search wikicommons
-#' wt_wikicommons_search(query = "Pinus")
+#' # FIXME: utf=FALSE for now until curl::curl_escape fix 
+#' # https://github.com/jeroen/curl/issues/228
+#' wt_wikicommons_search(query = "Pinus", utf8 = FALSE)
 #'
 #' ## use search results to dig into pages
-#' res <- wt_wikicommons_search(query = "Pinus")
+#' res <- wt_wikicommons_search(query = "Pinus", utf8 = FALSE)
 #' lapply(res$query$search$title[1:3], wt_wikicommons)
 #' }
 wt_wikicommons <- function(name, utf8 = TRUE, ...) {
@@ -53,12 +61,19 @@ wt_wikicommons_parse <- function(page, types = c("langlinks", "iwlinks",
 
   result <- wt_wiki_page_parse(page, types = types, tidy = tidy)
   json <- jsonlite::fromJSON(rawToChar(page$content), simplifyVector = FALSE)
+  # if output is NULL
   if (is.null(json$parse)) {
     return(result)
   }
+  # if page not found
+  txt <- xml2::read_html(json$parse$text[[1]])
+  html <- tryCatch(
+      xml2::xml_find_all(txt, 
+        "//div[contains(., \"Domain\") or contains(., \"Phylum\")]")[[2]], 
+      error = function(e) e)
+    if (inherits(html, "error")) return(list())
   ## Common names
   if ("common_names" %in% types) {
-    txt <- xml2::read_html(json$parse$text[[1]])
     vernacular_html <- xml2::xml_find_all(txt,
                                           xpath = "//bdi[@class='vernacular']")
     # XML formats:
@@ -81,18 +96,22 @@ wt_wikicommons_parse <- function(page, types = c("langlinks", "iwlinks",
   }
   ## classification
   if ("classification" %in% types) {
-    txt <- xml2::read_html(json$parse$text[[1]])
-    html <- xml2::xml_find_all(txt, "//div[contains(., \"APG IV\")]")
-    labels <- xml2::xml_text(xml2::xml_find_all(
-      html,
-      "b[not(following-sibling::*[1][self::a])]/following-sibling::text()[1] | b/following-sibling::*[1][self::a]/text()" #nolint
-    ))
-    labels <- gsub(
-      "^\\s+|\\s$|\\(|\\)", "",
-      gsub("^:\\s+|^\\s+\\u2022\\s+", "", labels)
-    )
-    values <- xml2::xml_text(xml2::xml_find_all(html, ".//b"))[-1]
+    html <- tryCatch(
+      xml2::xml_find_all(txt, 
+        "//div[contains(., \"Domain\") or contains(., \"Phylum\")]")[[2]], 
+      error = function(e) e)
+
+    # labels
+    labels <- c(gsub(":", "", strex(xml2::xml_text(html), "[A-Za-z]+\\)?:")[[1]]), "Authority")
+    labels <- gsub("\\(|\\)", "", labels)
+    labels <- labels[-1]
+
+    # values    
+    values <- xml2::xml_text(
+      xml2::xml_find_all(if (inherits(html, "xml_nodes")) html[[2]] else html, ".//b"))
     values <- gsub("^:\\s+|^.+:\\s?", "", values)
+    values <- values[-1]
+
     clz <- mapply(list, rank = labels, name = values,
                   SIMPLIFY = FALSE, USE.NAMES = FALSE)
     result$classification <- if (tidy) atbl(dt_df(clz)) else clz
