@@ -20,16 +20,21 @@
 #' @examples \dontrun{
 #' # high level
 #' wt_wikispecies(name = "Malus domestica")
+#' wt_wikispecies(name = "Pinus contorta")
+#' wt_wikispecies(name = "Ursus americanus")
+#' wt_wikispecies(name = "Balaenoptera musculus")
 #'
 #' # low level
 #' pg <- wt_wiki_page("https://species.wikimedia.org/wiki/Abelmoschus")
 #' wt_wikispecies_parse(pg)
 #'
 #' # search wikispecies
-#' wt_wikispecies_search(query = "pine tree")
+#' # FIXME: utf=FALSE for now until curl::curl_escape fix 
+#' # https://github.com/jeroen/curl/issues/228
+#' wt_wikispecies_search(query = "pine tree", utf8=FALSE)
 #'
 #' ## use search results to dig into pages
-#' res <- wt_wikispecies_search(query = "pine tree")
+#' res <- wt_wikispecies_search(query = "pine tree", utf8=FALSE)
 #' lapply(res$query$search$title[1:3], wt_wikispecies)
 #' }
 wt_wikispecies <- function(name, utf8 = TRUE, ...) {
@@ -65,7 +70,7 @@ wt_wikispecies_parse <- function(page, types = c("langlinks", "iwlinks",
     # name1, name2
     vernacular_html <- xml2::xml_find_all(
       xml,
-      "(//h2/span[contains(@id, 'Vernacular')]/parent::*/following-sibling::div)[1]" #nolint
+      "(//h2[contains(@id, 'Vernacular')]/parent::*/following-sibling::div)[1]"
     )
     languages_html <- xml2::xml_find_all(vernacular_html, xpath = "b")
     languages <- gsub("\\s*:\\s*", "",
