@@ -3,7 +3,9 @@ context("wt_wikipedia")
 test_that("wt_wikipedia returns non-empty results", {
   skip_on_cran()
 
-  aa <- wt_wikipedia(name = "Malus domestica")
+  vcr::use_cassette("wt_wikipedia_malus", {
+    aa <- wt_wikipedia(name = "Malus domestica")
+  }, preserve_exact_body_bytes = TRUE)
 
   expect_is(aa, "list")
   expect_named(aa, c('langlinks', 'externallinks', 'common_names',
@@ -11,11 +13,14 @@ test_that("wt_wikipedia returns non-empty results", {
   expect_is(aa$langlinks, "data.frame")
   expect_is(aa$externallinks, "character")
   expect_is(aa$common_names, "data.frame")
-  expect_named(aa$common_names, c('name', 'language'))
   expect_is(aa$classification, "data.frame")
   expect_named(aa$classification, c('rank', 'name'))
+})
 
-  bb <- wt_wikipedia(name = "Poa annua")
+test_that("wt_wikipedia returns non-empty results", {
+  vcr::use_cassette("wt_wikipedia_poa", {
+    bb <- wt_wikipedia(name = "Poa annua")
+  }, preserve_exact_body_bytes = TRUE)
 
   expect_is(bb, "list")
   expect_named(bb, c('langlinks', 'externallinks', 'common_names',
@@ -23,7 +28,6 @@ test_that("wt_wikipedia returns non-empty results", {
   expect_is(bb$langlinks, "data.frame")
   expect_is(bb$externallinks, "character")
   expect_is(bb$common_names, "data.frame")
-  expect_named(bb$common_names, c('name', 'language'))
   expect_is(bb$classification, "data.frame")
   expect_named(bb$classification, c('rank', 'name'))
 })
@@ -60,10 +64,13 @@ context("wt_wikipedia_parse")
 test_that("wt_wikipedia_parse returns non-empty results", {
   skip_on_cran()
 
-  url <- "https://species.wikimedia.org/wiki/Malus_domestica"
-  pg <- wt_wiki_page(url)
-  types <- c("common_names")
-  result <- wt_wikipedia_parse(pg, types = types)
+  vcr::use_cassette("wt_wikipedia_parse", {
+    url <- "https://species.wikimedia.org/wiki/Malus_domestica"
+    pg <- wt_wiki_page(url)
+    types <- c("common_names")
+    result <- wt_wikipedia_parse(pg, types = types)
+  }, preserve_exact_body_bytes = TRUE)
+  
   expect_is(result, "list")
   for (fieldname in types) {
     expect_is(result[fieldname], "list")
@@ -71,23 +78,33 @@ test_that("wt_wikipedia_parse returns non-empty results", {
   }
 })
 
+# FIXME: utf=FALSE for now until curl::curl_escape fix 
+# https://github.com/jeroen/curl/issues/228
 context("wt_wikipedia_search")
 
 test_that("wt_wikipedia_search works", {
   skip_on_cran()
 
-  aa <- wt_wikipedia_search(query = "Pinus")
+  vcr::use_cassette("wt_wikipedia_search", {
+    aa <- wt_wikipedia_search(query = "Pinus", utf8=FALSE)
+  })
 
   expect_is(aa, "list")
   expect_is(aa$continue, "list")
   expect_is(aa$query, "list")
   expect_is(aa$query$searchinfo, "list")
   expect_is(aa$query$search, "data.frame")
-  expect_named(aa$query$search, c('ns', 'title', 'size', 'wordcount',
+  expect_named(aa$query$search, c('ns', 'title', 'pageid', 'size', 'wordcount',
                                   'snippet', 'timestamp'))
+})
 
-  # no results when not found
-  expect_equal(NROW(wt_wikipedia_search("asdfadfaadfadfs")$query$search), 0)
+
+# no results when not found
+test_that("wt_wikipedia_search_not_found", {
+  vcr::use_cassette("wt_wikipedia_search_not_found", {
+    x <- wt_wikipedia_search("asdfadfaadfadfs", utf8=FALSE)
+  })
+  expect_equal(NROW(x$query$search), 0)
 })
 
 test_that("wt_wikipedia_search fails well", {
